VERSION 8000; ; 8200
* -----------------------------------------------------------------------------
* @filedoc
* @file DB_FlurstckslinieDatenZeigen83.CSX
* @brief Zugrif auf ODBC-Datenbank 
* 
* Dieses Beispielskript stellt eine Verbindung zu einer ODBC-Datenbank her, z.B. CARD/1 Grunderwerbsdatenbank.
* Es werden Flurstckslinien farblich hervorgehoben, die mit einem Sachdatensatz verknpft sind.
*
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author RM
* @endfiledoc
* -----------------------------------------------------------------------------
*     8200 18.05.09 JH Anpassungen zur 8.2
* @history
* -----------------------------------------------------------------------------


* --- Vereinbarungen ----------------------------------------------------------

BILDSCHIRM GRAFIK                          | gibt die Meldungen im Arbeitsprotokoll aus


* --- Implizite Deklarationen -------------------------------------------------

!Name_FlstSchicht = "Flurstcke"           | Name der Flurstcksschicht


* --- Explizite Deklarationen -------------------------------------------------

* Systemobjekt
SYMBOLE /TOPOSYS/ Toposys                  | Symbol fr das System der Topografiedaten

* Topografieojekte
SYMBOLE /TOPOLINE/ Linie                   | Symbol fr die Topografielinie
SYMBOLE /TOPOLINEINDEX/ XLinie             | Symbol fr das Linienindexobjekt 

* Datenbankobjekte
SYMBOLE /DBCONNECTION/ DataBase            | Symbol fr Datenbankzugriff
SYMBOLE /DBCOMMAND/ Stmt                   | Symbol fr DB-Anweisung

SYMBOLE * kk                               | Symbol fr DB-Verbindungsstatus                         


* Ausfhrungen ----------------------------------------------------------------

* Systemobjekte 
Toposys = Project.GetTopoSys()
DataBase = Project.GetDataBase()

*** Verbindung mit ODBC-Datenbank des akt. Projektes herstellen
kk = DataBase.Connect(!ProjektODBC(); ""; ""; "ODBC")

MELDE "Verbindungsstatus: # (Version #)"; kk; !!DataBase.GetVersion()
MELDE "(1 = Verbindung ist hergestellt)"

WENN kk <> 1 DANN                                                         | wenn DB nicht ordnungsgem verbunden: Abbruch
  TEXTGEN !Meldung; "ODBC-Datenbank # konnte nicht geffnet werden"; !ProjektODBC()
  MELDUNG FEHLER !Meldung
  STOP 
WEITER


*** Schleife zum Auslesen der Linien ber gesetzte Filter

* Linienindexobjekt:  Auswahl der Linien ber Schicht, Kode und Markierung
XLinie = TopoSys.GetLineIndex(!Name_FlstSchicht)                          | liefert das Linienindexobjekt der Schicht
XLinie.SetCodeRange(233; 233)                                             | setzt einen Kodefilter fr Flurstckslinien
XLinie.SetMarked(1)                                                       | setzt einen Markierfilter

* Linienobjekt
SOLANGE Linie = XLinie.GetNext()                                          | liest Linien ber gesetzte Filter aus

  LP_Id = Linie.GetDataLink(1)                                            | liefert fr die Linie die ID des verknpften Sachdatensatzes

  WENN LP_Id > 0 DANN                                                     | Linie hat einen verknpften Sachdatensatz
  
    Linie.Draw(6)                                                         | visualisiert die Linie gelb
    
    * DB-Anweisung fr die Ausfhrung vorbereiten: Abrufen von Datenstzen aus einer Tabelle
    TEXTGEN !SQLSequenz; "SELECT * FROM Flurstueck_CRD WHERE [Flurstueck_CRD].[P_ID]=#;"; LP_Id
    Stmt = DataBase.CreateCommand(!SQLSequenz)                            | View auf Flurstckstabelle mit nur dem Datensatz, der zur Linie gehrt
    * DB-Anweisung SELECT ausfhren
    kk = Stmt.Execute();
    * Datenstze ermitteln
    iostat = Stmt.GetNextRow()                                            | liefert die nchste Datensatzzeile (hier: erste und einzige)
    WENN iostat == 0 DANN
      MELDUNG FEHLER "Der Datensatz zur aktuellen Linie wurde nicht gefunden"
    SONST
      !Flurstueck_Nr = Stmt.GetStringByName("Flurstueck_Zaehler")         | liefert Zhler aus DB 
      !Flurstueck_Nenner = Stmt.GetStringByName("Flurstueck_Nenner")      | liefert Nenner aus DB 
      !FlstBemerkung = Stmt.GetStringByName("Bemerkung")                  | liefert Bemerkung aus DB 
      WENN T_LANG(!Flurstueck_Nenner) > 0 DANN !Flurstueck_Nr = !Flurstueck_Nr + "/" + !Flurstueck_Nenner
      TEXTGEN !Meldung; "Die gelbe Linie ist Flurstck # und hat die Flurstcksbemerkung '#'"; !Flurstueck_Nr; !FlstBemerkung
      MELDUNG WEITER; !Meldung; weiter; 1
      WENN weiter == -1 DANN STOP
    WEITER
    Linie.Draw(4)                                                         | visualisiert Linie wieder grn, damit es nur eine aktuelle gelbe gibt
    * DB-Anweisung auf 'undefiniert' setzen
    Stmt = $NULL
    
  WEITER
  
ENDE SOLANGE

*** Ende Schleife 

PAUSE "Ende"

STOP


* --- Funktionsblock -----------------------------------------------
* @function !ProjektODBC
* @brief Liefert ODBC-Namen der Grunderwerbsdatenbank des aktuellen Projekts
*
* @ingroup
* @author RM
* @endfunction
FUNKTION !ProjektODBC:

  !ODBCName = Project.GetName()
  !ODBCName = !_TEIL(!ODBCName; 1; 27)
  !ODBCName = "___________________________82" & !ODBCName
  
  ZURUECK !ODBCName
ENDE FUNKTION